/*-- Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
Model         	FAW - Model Management Product Lifecycle Tab  
Subject Area  	Product Lifecycle
Version
Name          	DDCF 5.3: Macro to export Act-like dtls.  
DBMS          	SAS
Created by 		SAS R & D, Pune India.
Created on 		20/01/2014 11:54:00 AM
Last updated 	20/01/2014 11:54:00 AM

* Copyright (c) 2014 by SAS Institute Inc., Cary, NC 27513

Input Parameters 
None

History:

*/

%macro ddcf_plc_export_act_like_dtls() ;

	%let job_rc=0;
	%let job_rc_msg=;

	/******* WORKFLOW: Step 1: Data Preparation. */

	%if not %sysfunc(exist(work.final_phase_in_tmp4)) %then %do;
		%put NOTE: work.final_phase_in_tmp4 table does not exist.;
		%goto exit;
	%end;
	

	/* Derive Predecessor and Sucessor Details with relations */
	
	proc sql noprint;
		create table work.act_like_tmp1
		as
		select a.*,b.dim_rltn_dtls_id,b.act_like_dim_rltn_dtls_id,b.scaling_factor as scale_factor
		from uiart.phase_in_dtls a left join uiart.phase_in_rltn b
		on a.phase_in_id=b.phase_in_id 
		where b.act_like_dim_rltn_dtls_id ne .;

		create table work.act_like_tmp2
		as
		select a.*,b.plc_relation_no as plc_relation_no
		from work.act_like_tmp1 a left join work.final_phase_in_tmp4 b
		on a.product_rk = b.product_rk and a.dim_rltn_dtls_id = b.dim_rltn_dtls_id
		and a.phase_in_id = b.phase_in_id; 

		create table work.final_act_like_tmp3
		as
		select a.*,b.plc_relation_no as act_like_plc_relation_no
		from work.act_like_tmp2 a left join work.final_phase_in_tmp4 b
		on a.product_rk = b.product_rk and a.act_like_dim_rltn_dtls_id = b.dim_rltn_dtls_id;

	quit;
	%rcset(&sqlrc);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred exporting ACT_LIKE_DTLS table.;
		%goto exit;
	%end; 


	/*************** START: Final Load ***************/

	proc append base=&libout..stg_act_like_rltn_dtls data=work.final_act_like_tmp3 force nowarn;
	run;
	%rcset(&syserr);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred while loading stg_act_like_rltn_dtls table.;
		%goto exit;
	%end; 

/*************** END: Final Load ***************/	


%exit:
%mend;
