/*-- Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
Model         	FAW - Model Management Product Lifecycle Tab  
Subject Area  	Product Lifecycle
Version
Name          	DDCF 5.3: Main macro to export product lifecycle data.  
DBMS          	SAS
Created by 		SAS R & D, Pune India.
Created on 		20/01/2014 11:54:00 AM
Last updated 	20/01/2014 11:54:00 AM

* Copyright (c) 2014 by SAS Institute Inc., Cary, NC 27513

Input Parameters 
None

History:

*/

%macro ddcf_plc_export_data(libout=scratch) ;

	%let job_rc=0;
	%let job_rc_msg=;

/******* WORKFLOW: Step 1: Data Preparation. */

	%if not %sysfunc(exist(uiart.phase_in_dtls)) %then %do;
		%put NOTE: uiart.phase_in_dtls table does not exist.;
		%goto exit;
	%end;
	%if not %sysfunc(exist(uiart.phase_in_rltn)) %then %do;
		%put NOTE: uiart.phase_in_rltn table does not exist.;
		%goto exit;
	%end;

	%if not %sysfunc(exist(uiart.dim_rltn_dtls)) %then %do;
		%put NOTE: uiart.dim_rltn_dtls table does not exist.;
		%goto exit;
	%end;

	%if not %sysfunc(exist(uiart.phase_out_dtls)) %then %do;
		%put NOTE: uiart.phase_out_dtls table does not exist.;
		%goto exit;
	%end;

	%if not %sysfunc(exist(uiart.phase_out_rltn)) %then %do;
		%put NOTE: uiart.phase_out_dtls table does not exist.;
		%goto exit;
	%end;

	%if not %sysfunc(exist(uiart.successor_dtls)) %then %do;
		%put NOTE: uiart.successor_dtls table does not exist.;
		%goto exit;
	%end;

	%if not %sysfunc(exist(uiart.successor_rltn)) %then %do;
		%put NOTE: uiart.successor_rltn table does not exist.;
		%goto exit;
	%end;


	%global plan_dimkeys plan_dimpkeys dimcnt;

	proc sql noprint;

		%let plan_dimkeys=;
		%let plan_dimpkeys=;
		%let dimcnt=;

		/* Derive list of dimensions used for a plc. */

		create table work.plan_lc_info
		as
		select distinct dim_rk,
				primary_rk_nm,
				tranwrd(ktrim(kleft(primary_rk_nm)),'RK','NM') as primary_key_nm,
				ktrim(kleft(klowcase(dim_nm))) || "_lkup" as lkup_table_nm,
				ktrim(kleft(klowcase(dim_nm))) as source_table_nm
		from config.dim_table_list
		where kupcase(ktrim(kleft(valid_dim_flg))) = %sysfunc(kupcase(%sysfunc(ktrim(%sysfunc(kleft("&GL_SHORT_YES."))))))
		/*and quantitative_dim_ind = 0*/
		order by dim_rk;

		select 	dim_rk,
				primary_rk_nm,
				primary_key_nm,
				lkup_table_nm,
				source_table_nm,
 				primary_rk_nm
				into 
				:plan_dimkeys separated by ',',
				:plan_dimpkeys separated by ',',
				:plan_dimpnmkeys separated by ',',
				:lkup_table_nms separated by ',',
				:source_table_nms separated by ',',
				:plan_pks separated by ' '
		from work.plan_lc_info
		where dim_rk ne 1;

		select count(*) into :dimcnt
		from work.plan_lc_info
		where dim_rk ne 1;

		%put &dimcnt.;
		%put &plan_dimpkeys.;

	quit;
	%rcset(&sqlrc);
	%if (&job_rc. >4 ) %then %do;
		%put "ERROR: While deriving list of dimensions.";
		%goto exit;
	%end;

/******* WORKFLOW: Create STAGEOUT Tables. */

	%ddcf_plc_export_stageout_ddl;

/******* WORKFLOW: Export-Phase-in-Phase-Out Details. */
	
	%ddcf_plc_export_phase_in_dtls;

/******* WORKFLOW: Export-Successor Details */

	%if (&job_rc. >4 ) %then %do;
		%put "ERROR: While deriving Phase-in Phase-out Details.";
		%goto exit;
	%end;

	%ddcf_plc_export_successor_dtls;
	
/******* WORKFLOW: Export-Act-like Details */

	%if (&job_rc. >4 ) %then %do;
		%put "ERROR: While deriving Successor Details.";
		%goto exit;
	%end;

	%ddcf_plc_export_act_like_dtls;

	%if (&job_rc. >4 ) %then %do;
		%put "ERROR: While deriving Act-like Details.";
		%goto exit;
	%end;
	
%exit:
	%ddcf_clear_work_lib;
%mend;
