/*-- Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
Model         	FAW - Model Management Product Lifecycle Tab  
Subject Area  	Product Lifecycle
Version
Name          	DDCF 5.3: Macro to export Phase-in Phase-out dtls.  
DBMS          	SAS
Created by 		SAS R & D, Pune India.
Created on 		20/01/2014 11:54:00 AM
Last updated 	20/01/2014 11:54:00 AM

* Copyright (c) 2014 by SAS Institute Inc., Cary, NC 27513

Input Parameters 
None

History:

*/

%macro ddcf_plc_export_phase_in_dtls() ;

	%let job_rc=0;
	%let job_rc_msg=;

	/* Derive phase-in details with relations */
	
	proc sql noprint;
		create table work.phase_in_tmp1
		as
		select a.*,b.dim_rltn_dtls_id
		from uiart.phase_in_dtls a left join uiart.phase_in_rltn b
		on a.phase_in_id=b.phase_in_id;

		create table work.phase_in_tmp2
		as
		select a.product_rk,
			%do i = 1 %to &dimcnt.;  
				%let rk_string = %sysfunc(kscan(%bquote(&plan_dimpkeys.),&i.));
				b.&rk_string. , 
			%end;
			a.phase_in_id,
			a.dim_rltn_dtls_id,
			a.phase_in_dt format=nldate.
		from work.phase_in_tmp1 a left join uiart.dim_rltn_dtls b
		on a.dim_rltn_dtls_id=b.dim_rltn_dtls_id;

	quit;
	%rcset(&sqlrc);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred exporting PHASE_IN_PHASE_OUT_DTLS table.;
		%goto exit;
	%end; 

	/* Derive phase-out date */
	proc sql noprint;
		create table work.phase_out_tmp1 as
		select a.phase_in_id,a.phase_out_id,a.product_rk,a.phase_out_dt, b.dim_rltn_dtls_id,a.temp_phase_in_dt as rephase_in_dt format=nldate.
		from uiart.phase_out_dtls a, uiart.phase_out_rltn b
		where a.phase_out_id = b.phase_out_id; 
	quit;

	%rcset(&sqlrc);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred exporting PHASE_IN_PHASE_OUT_DTLS table.;
		%goto exit;
	%end;

	proc sql noprint;
		create table work.phase_in_tmp3
		as
		select monotonic() as plc_relation_no, a.*,b.phase_out_id,coalesce(b.phase_out_dt,.) as phase_out_dt format=nldate.,rephase_in_dt
		from work.phase_in_tmp2 a left join work.phase_out_tmp1 b
		on a.phase_in_id=b.phase_in_id and a.dim_rltn_dtls_id = b.dim_rltn_dtls_id and a.product_rk = b.product_rk;

	quit;
	%rcset(&sqlrc);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred exporting PHASE_IN_PHASE_OUT_DTLS table.;
		%goto exit;
	%end;

	/* Derive Business Id's for a Table. */

	proc sql noprint;

		select 	ktrim(primary_rk_nm),ktrim(dim_nm) || '_lookup',ktrim(dim_id) 
				into :rkcolumns separated by ',', :lkup_table_nms separated by ',',:idcolumns separated by ','
		from config.dim_table_list
		where kupcase(ktrim(kleft(valid_dim_flg))) = %sysfunc(kupcase(%sysfunc(ktrim(%sysfunc(kleft("&GL_SHORT_YES."))))))
		/*and quantitative_dim_ind = 0*/
		order by dim_rk;

	quit; 
	%rcset(&sqlrc);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred exporting PHASE_IN_PHASE_OUT_DTLS table.;
		%goto exit;
	%end; 
	
	data work.final_phase_in_tmp4(drop=rc: );

		%let k=0;

		%if &dimcnt. gt 0 %then %do;

			%let j=1;

			%let alist=%sysfunc(kscan(%quote(%sysfunc(strip(&rkcolumns.))),&j., %str(,)));
			%let blist=%sysfunc(kscan(%quote(%sysfunc(strip(&idcolumns.))),&j., %str(,)));
			%let clist=%sysfunc(kscan(%quote(%sysfunc(strip(&lkup_table_nms.))),&j., %str(,)));

			%do %while (%quote(&alist.) ne);

				%let primary_key_nm=%sysfunc(kscan(&alist.,1));
				%let id_nm=%sysfunc(kscan(&blist.,1));
				%let lkup_table_nm=%sysfunc(kscan(&clist.,1));

				declare hash h&k.();
				rc&k. = h&k..definekey("&primary_key_nm.");
				rc&k. = h&k..definedata("&id_nm.");
				rc&k. = h&k..definedone();

				do until(eof&k.);
					set sdl.&lkup_table_nm. (rename=(id=&id_nm. rk=&primary_key_nm.)) end=eof&k.;
					rc&k. = h&k..add();
		      	end;

				%let k=%eval(&k.+1);
				%let j=%eval(&j.+1);

				%let alist=%sysfunc(kscan(%quote(%sysfunc(strip(&rkcolumns.))),&j., %str(,)));
				%let blist=%sysfunc(kscan(%quote(%sysfunc(strip(&idcolumns.))),&j., %str(,)));
				%let clist=%sysfunc(kscan(%quote(%sysfunc(strip(&lkup_table_nms.))),&j., %str(,)));

			%end;
		%end;

	 	do until(eof);
              set work.phase_in_tmp3 end=eof;

              %let k=0;

              %let j=1;

              %let alist=%sysfunc(kscan(%quote(%sysfunc(strip(&idcolumns.))),&j., %str(,)));

              %do %while (%quote(&alist.) ne);

                    %let id_nm=%sysfunc(kscan(&alist.,1));

                    call missing(&id_nm.);
                    rc&k. = h&k..find();

                    %let k=%eval(&k.+1);
                    %let j=%eval(&j.+1);

                    %let alist=%sysfunc(kscan(%quote(%sysfunc(strip(&idcolumns.))),&j., %str(,)));

              %end;
			  output;
        end;
        stop;
    run;
	%rcset(&syserr);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred while deriving id columns for output table.;
		%goto exit;
	%end; 

	/*************** START: Final Load ***************/

	proc append base=&libout..stg_phase_in_phase_out_dtls data=work.final_phase_in_tmp4 force nowarn;
	run;
	%rcset(&syserr);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred while loading stg_phase_in_phase_out_dtls table.;
		%goto exit;
	%end; 

/*************** END: Final Load ***************/	


%exit:
%mend;
