
/*-- Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
Model         	FAW FM Integration  
Subject Area  	FAW Product LifeCycle
Version
Name          	FAW 5.2 M2: DDL Script to create PLC stage out tables for export.
Created by 		SAS R & D Pune, India.
Created on 		10/09/2014 10:05:00 AM
Last updated 	10/09/2014 10:05:00 AM

* Copyright (c) 2014 by SAS Institute Inc., Cary, NC 27513

Input Parameters 

History:

*/


%macro ddcf_plc_export_stageout_ddl() ;
	
	%let job_rc=0;
	%let job_rc_msg=;

	/* Derive valid id columns list. */

	%let plcids=;
	%let plcdimcnt=0;

	proc sql noprint;
		select dim_id into :plcids separated by ','
		from config.dim_table_list
		where kupcase(ktrim(kleft(valid_dim_flg))) = %sysfunc(kupcase(%sysfunc(ktrim(%sysfunc(kleft("&GL_SHORT_YES."))))))
		/*and quantitative_dim_ind = 0 */
		order by dim_rk;
		
		select count(*) into :plcdimcnt
		from config.dim_table_list
		where kupcase(ktrim(kleft(valid_dim_flg))) = %sysfunc(kupcase(%sysfunc(ktrim(%sysfunc(kleft("&GL_SHORT_YES."))))))
		/*and quantitative_dim_ind = 0*/
		;
	quit;
	%rcset(&sqlrc);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error ocured while deriving id columns list for creating Product LifeCycle Batch STAGEOUT Tables.;
		%goto exit;
	%end;


	%if &plcdimcnt. gt 0 %then %do;

		proc sql noprint;

			%if %sysfunc(exist(&libout..stg_phase_in_phase_out_dtls)) %then %do;
				drop table &libout..stg_phase_in_phase_out_dtls;
			%end;

			create table &libout..stg_phase_in_phase_out_dtls
			( 
				PLC_RELATION_NO numeric(8) label='Product Lifecycle Relationship No',

				%do i=1 %to &plcdimcnt.;
					  	%let varnm = %sysfunc(kscan(%bquote(&plcids.),&i.));
					  	&varnm. varchar(32) label="&varnm.", 
				%end;
				PHASE_IN_DT numeric(8) label='Product Phase-in Date' format=NLDATE.,
				PHASE_OUT_DT numeric(8) label='Product Phase-out Date' format=NLDATE.,
				REPHASE_IN_DT numeric(8) label='Product Phase-out Date' format=NLDATE.
			);

		
			%if %sysfunc(exist(&libout..stg_successor_rltn_dtls)) %then %do;
				drop table &libout..stg_successor_rltn_dtls;
			%end;

			create table &libout..stg_successor_rltn_dtls
			(
				PREDECESSOR_PLC_RELATION_NO numeric(8) label='Predecessors Product Lifecycle Relationship No',
				SUCCESSOR_PLC_RELATION_NO numeric(8) label='Successors Product Lifecycle Relationship No',
				SCALE_FACTOR numeric(8) label='Scale Factor'
			);
		

			%if %sysfunc(exist(&libout..stg_act_like_rltn_dtls)) %then %do;
				drop table &libout..stg_act_like_rltn_dtls;
			%end;
			
			create table &libout..stg_act_like_rltn_dtls
			(
				PLC_RELATION_NO numeric(8) label='Product Lifecycle Relationship No',
				ACT_LIKE_PLC_RELATION_NO numeric(8) label='Act-like Product Lifecycle Relationship No',
				SCALE_FACTOR numeric(8) label='Scale Factor'
			);
		quit;
		%rcset(&sqlrc);
		%if (&job_rc. >4 ) %then %do;
			%put ERROR: An error ocured while creating Product LifeCycle Batch STAGEOUT Tables.;
			%goto exit;
		%end;
	%end;


%exit:
%mend;
