/*-- Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
Model         	FAW - Model Management Product Lifecycle Tab  
Subject Area  	Product Lifecycle
Version
Name          	DDCF 5.3: Macro to export Succesor dtls.  
DBMS          	SAS
Created by 		SAS R & D, Pune India.
Created on 		20/01/2014 11:54:00 AM
Last updated 	20/01/2014 11:54:00 AM

* Copyright (c) 2014 by SAS Institute Inc., Cary, NC 27513

Input Parameters 
None

History:

*/

%macro ddcf_plc_export_successor_dtls() ;

	%let job_rc=0;
	%let job_rc_msg=;

	/******* WORKFLOW: Step 1: Data Preparation. */

	%if not %sysfunc(exist(work.final_phase_in_tmp4)) %then %do;
		%put NOTE: work.final_phase_in_tmp4 table does not exist.;
		%goto exit;
	%end;
	

	/* Derive Predecessor and Sucessor Details with relations */
	
	proc sql noprint;
		create table work.predecessor_successor_tmp1
		as
		select a.*,b.dim_rltn_dtls_id,b.share_pct as scale_factor
		from uiart.successor_dtls a left join uiart.successor_rltn b
		on a.succ_id=b.succ_id;

		create table work.predecessor_successor_tmp2
		as
		select a.succ_id,
			a.product_rk,
			a.succ_prod_rk,
			a.succ_phase_in_id,
			a.phase_out_id,
			%do i = 1 %to &dimcnt.;  
				%let rk_string = %sysfunc(kscan(%bquote(&plan_dimpkeys.),&i.));
				b.&rk_string. , 
			%end;
			a.dim_rltn_dtls_id,
			a.scale_factor
		from work.predecessor_successor_tmp1 a left join uiart.dim_rltn_dtls b
		on a.dim_rltn_dtls_id=b.dim_rltn_dtls_id;

		create table work.predecessor_successor_tmp3
		as
		select a.*,b.plc_relation_no as predecessor_plc_relation_no
		from work.predecessor_successor_tmp2 a left join work.final_phase_in_tmp4 b
		on a.product_rk = b.product_rk and a.dim_rltn_dtls_id = b.dim_rltn_dtls_id
		and a.phase_out_id = b.phase_out_id; 

		create table work.final_successor_tmp4
		as
		select a.*,b.plc_relation_no as successor_plc_relation_no
		from work.predecessor_successor_tmp3 a left join work.final_phase_in_tmp4 b
		on a.succ_prod_rk = b.product_rk and a.dim_rltn_dtls_id = b.dim_rltn_dtls_id
		and a.succ_phase_in_id = b.phase_in_id; 

	quit;
	%rcset(&sqlrc);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred exporting SUCCESSOR_DTLS table.;
		%goto exit;
	%end; 


	/*************** START: Final Load ***************/

	proc append base=&libout..stg_successor_rltn_dtls data=work.final_successor_tmp4 force nowarn;
	run;
	%rcset(&syserr);
	%if (&job_rc. >4 ) %then %do;
		%put ERROR: An error occurred while loading stg_successor_rltn_dtls table.;
		%goto exit;
	%end; 

	/*************** END: Final Load ***************/	


%exit:
%mend;
