
/**********************************************************************************************
-- Copyright (c) 2011 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --
* Copyright (c) 2011 by SAS Institute Inc., Cary, NC 27513

Model         	DDCF Configuration 1.0 
Subject Area  	Running Plan in batch process or Refresh
Version
Name          	This script refresh reloads all the data in UIARTs while plan is run in refresh or batch process
DBMS          	SAS
Creation Date 	October 2011

NOTE:

ddcf_hpf_engine.sas file is present as uncompiled macro for customization purpose.
If necessary, the 'STOCHASTIC' statement can be replaced by 'CONTROL' statement as given in the uncompiled version.
It can be saved in the server and the 'path of stored process file' needs to be included in the '%include' statement below and line should be uncommented.
The EXTEND option can be changed from 'AVERAGE' to NONE, FIRST, LAST, MEDIAN, STOCHASTIC, MINIMUM, MAXIMUM.
***********************************************************************************************/
/*%include "path of stored process file\ddcf_hpf_engine.sas";*/


%macro ddcf_create_forecast_plan;


%Global rediagnose_flg;
%let rediagnose_flg=;

	%global job_rc  userName _nolog_passwd GL_FS_PROJ_DESKTOP;

	%let GL_FS_PROJ_DESKTOP=NO;

	%global plan_id edit_flag batch_process;
	%let plan_id= &plan_id;
	%local plan_status ;

	 %let ui_libref=uiart;



	%ddcf_declare_global_variables;

	%if &batch_process=1 %then %do;

		proc sql;
			update uiart.plan_details set PLAN_STATUS_NO = 17 where plan_id = &plan_id.;
		quit;

	%end;

        %let  edit_flag = 0;   

	/*for deleting the plan*/
	%if &edit_flag.=1 %then %do;
		%ddcf_delete_plan;
	 	proc sql noprint;
			select count(*) into: plan_error
			     from uiart.plan_details 
				where plan_id=&plan_id.
				and PLAN_STATUS_NO=6;
			quit;

			%let plan_error=&plan_error.;
	     /* if any error has occured while deletion of fs proj then go to end and update the 
			plan_operation and plan_details table as 'error while deletion'*/
			%if &plan_error.>0 %then %do;	
			
				%goto end_plan;

			%end;
	%end;
	/* For Creating the table with the total thread number for each plan */
	%let table_exist = %sysfunc(exist(config.plan_thread));
    %if &table_exist. eq 0 %then %do;
        proc sql noprint;
                 create table config.plan_thread 
                 (
                   plan_id num format = best12. informat = best12.,
                   thread_num num format = best12. informat = best12.
                  );
                 quit; 

     %end;
		 %ddcf_util_lock(config.plan_thread);

		  proc sql noprint;
            insert into config.plan_thread
            values(&plan_id.,&GL_FORECAST_THREADS_NO.)
            ;
          quit;

		 %ddcf_util_unlock(config.plan_thread);

	/*%ddcf_plan_hier_filter_leaf;*/
	%ddcf_initiate_abt_creation;
/*	%ddcf_initiate_abt_indep_creation;*/

	%ddcf_create_plan_stf_abt;

	%if &indep_num. > 0 %then %do;
        %ddcf_stf_npf_abt_indep;
    %end;

/*	%ddcf_plan_create_successors_abt;*/

    %ddcf_call_hier_creation;

	%if &indep_num. > 0 %then %do;
       %ddcf_call_hier_creation_indep;
    %end;


    /* if any error has occured while deleting a plan, then no need of creating the plan again, 
	   only show the error message in plan_details*/
    %end_plan:

%mend ddcf_create_forecast_plan;

%macro ddcf_diagnose_forecast_plan;



	%global adhoc_process_flg PLAN_VALID_DATA_FLG;
	%let adhoc_process_flg=&GL_SHORT_YES.;
	%local plan_status ;

	%global call_from_forecast;
	%let call_from_forecast = &GL_SHORT_YES.;

	%global drive_nm FORECAST_METHOD;
	%let drive_nm = &GL_DATA_STORAGE_PATH.;
	%let FORECAST_METHOD = HPF;
	%ddcf_plan_spec;
	%ddcf_call_set_params_libnames;


	/* added for retain model functionality */
	%if &rediagnose_flg = 1 %then %do;
			data control.plan_valid_data_flg&plan_id.;
			set control.plan_valid_data_flg&plan_id.;
			incre_fcst_flag = "&gl_short_no.";
			run;
	%end;
	 
	/* Update plan and time series specific parameter in hpf_preference&plan_id table*/
	%ddcf_update_hpf_param_for_proc 

	/*   option sascmd="!sascmd -memsize 3G";*/

	  option autosignon=YES sascmd="!sascmd";

	/* Forecasting Store Proc */

	/* added to handle multiple parallel processing */
	%if &GL_OPT_FLAG. eq &GL_SHORT_YES. %then %do;
	%ddcf_bef_ent_mp_connect(lib =uiart , file =connect_flg , column =flag );
	%end;

	%ddcf_call_diagnose_engine_mac;

	/* Only in case, the optimization flag is set to Y, signoff is required.*/
	 
	 %if &GL_OPT_FLAG. eq &GL_SHORT_YES. %then %do;

	 %ddcf_signoff_statements;

	 %ddcf_immediate_after(lib =uiart , file = connect_flg, column = flag); 


	 %end; 

	/* Reconcile Store Proc */
	%ddcf_call_reconcile_mac;

	%if &GL_OPT_FLAG. eq &GL_SHORT_YES. %then %do;

			%global drive_nm FORECAST_METHOD;
			%let drive_nm = &GL_DATA_STORAGE_PATH.;
	        %let FORECAST_METHOD = HPF;
		%ddcf_call_set_params_libnames;
	 
	%end; 

%mend ddcf_diagnose_forecast_plan;


%macro ddcf_uiart_batch_refresh;

	%local plan_status ;
	%global only_npf;

	%let job_rc=0;
	%let job_rc_msg=;
	%let plan_status=;

	proc sql;
	select plan_valid_data_flg into : valid_flg from control.Plan_valid_data_flg&plan_id. ;
	select only_npf_data_flg  into : only_npf from control.Plan_valid_data_flg&plan_id. ;
	quit;

	%RCSet(&sqlrc);
	%if (&job_rc>4) %then %do;
		%let plan_status = 7;
		%goto exit;
	%end;

	%put &valid_flg.;

	%if "&valid_flg." = "N" %then %do;
		/*No data selected - Error in plan creation*/
		%let plan_status = 7;
		%let error_status_uiart= 1;
		%put "ERROR: No Valid data found";
		/*Defect - S0795692 : Error code will be updated with No valid data selected*/
		proc sql noprint;
			update uiart.plan_details set ERROR_CD = "DDF_ERR_001" where plan_id = &plan_id.;
		quit;
		%goto exit;
	%end;

	%if "&valid_flg." = "Y" %then %do;
		/*SHK*/
		%ddcf_update_horizon_start_dt;

		/*After Forecasting Stored Proc -*/
		/*Updating Model Management tables with forecasted values*/
		%ddcf_uiart_get_plan_fcst_dtls;
		%ddcf_uiart_mixed_dim_hierarchy;

		%if &error_status_uiart. = 1 %then %do;
			%let plan_status = 7;
			%goto exit;
		%end;
		
		/*Filters*/
		%ddcf_upd_mixed_dim_success_ind;
		%ddcf_upd_mixed_dim_lifecycleind;
		%ddcf_upd_mixed_dim_hier_bom_ind;
		%ddcf_upd_mixed_dim_low_hist_ind;

		
		%if "&only_npf." = "N" %then %do;

			/* Filters for series properties and forecast quality */
			%ddcf_upd_mixed_dim_hier_sertype;
			%if &error_status_uiart. = 1 %then %do;
				%let plan_status = 7;
				%goto exit;
			%end;

			%ddcf_upd_mixed_dim_fcst_qlty;
			%if &error_status_uiart. = 1 %then %do;
				%let plan_status = 7;
				%goto exit;
			%end;

			%ddcf_upd_mixed_dim_pred_measures;
			%if &error_status_uiart. = 1 %then %do;
				%let plan_status = 7;
				%goto exit;
			%end;

			/***/
			%ddcf_uiart_mixed_dim_hier_updt;
			%ddcf_uiart_fcst_model_dtls;
			%ddcf_uiart_fcst_mdl_rslt_iv_op;
			%ddcf_uiart_fcst_event_summ;

			%if &error_status_uiart. = 1 %then %do;
				%let plan_status = 7;
				%goto exit;
			%end;

		%end;
		%else %do;
			%ddcf_create_fcst_mdl_event_summ(library=uiartsas ,tabname=fcst_mdl_rslt_event_summary&plan_id.);
			%ddcf_create_fcst_mdl_iv_summ(library=uiartsas ,tabname=fcst_mdl_rslt_iv_summary&plan_id.);
		%end;

		%ddcf_uiart_fcst_mdl_summ_updt;

		%if &error_status_uiart. = 1 %then %do;
			%let plan_status = 7;
			%goto exit;
		%end;
		
		
		/* MK - Update dimension name and count for a plan in uiart.plan_dimensions table */
		%ddcf_get_plan_dim_rec_cnt;
		%if &error_status_uiart. = 1 %then %do;
			%let plan_status = 7;
			%goto exit;
		%end;


		/* MK - update forecast status code for time series that are added through NPF workflow */
		%ddcf_upd_npf_plan_fcst_status;
		%if &error_status_uiart. = 1 %then %do;
			%let plan_status = 7;
			%goto exit;
		%end;

		/*SH*/
		%ddcf_update_no_of_series;

		/* Updates the low history indicator in plan_details table, if all the time series of the plan are low history timeseries*/
		%if "&only_npf." = "Y"  %then %do; 
			proc sql noprint;
				update uiart.plan_details set LOW_HISTORY_IND = 1 where plan_id = &plan_id.;
			quit;
		%end;

		/* updates hpf_start date in plan_set_param table*/
		%ddcf_uiart_plan_set_param_updt;

		

		proc sql noprint;
			select EXPLODE_BOM into: explode_bom_flg from uiart.plan_details where plan_id = &plan_id.;
		quit;

		%if &explode_bom_flg. eq 1 %then %do; 
			%ddcf_populate_fcst_child_prod;
		%end;
		
		/* Generate tables for reporting in archive folder */
/*		%if &GL_INCLUDE_ARCHIVE_IND. = 1 %then %do;*/
/*			%ddcf_generate_forecast_reports(plan_id = &plan_id.);*/
/*		%end;*/

		/* To populate the abt.Plan_leaf_lvl_disagg*/
		%ddcf_dim_leaf_lvl_disagg;

		/* To populate the tables for product life cycle tab*/
		%ddcf_load_uiart_product_lc_data(plan_id=&plan_id.);

%end;

/*KK ** Updating the status in plan detail table in UIART -- Forecasted=4	*/
proc sql noprint;
	select count(*) into :compl from uiartsas.FCST_MDL_RSLT_SUMMARY&plan_id. where PREDICTED_DEMAND NE . or ACTUAL_DEMAND NE .;
quit;
/*Above statement fails - if table does not exist then error*/
%ddcf_set_rc(&sqlrc);
%if (&job_rc>4) %then %do;
	%let plan_status = 7;
	%goto exit;
%end;
%else %if &compl. >0 %then %do ;
	%let plan_status = 4;
	%goto exit;
%end;
%else %do;
	%let plan_status = 7;
	%goto exit;
%end;

%exit:

/*Updates the final status in plan details table*/
proc sql noprint;
	update uiart.plan_details set PLAN_STATUS_NO = &plan_status. where plan_id = &plan_id.;
	%if &error_status_uiart. = 1 %then %do;
	update uiart.plan_details set PLAN_STATUS_NO = 7 where plan_id = &plan_id.;
	%end;
quit;



%mend;
%macro ddcf_upd_plan_run_dttm;

proc sql;
	update uiart.plan_details  
	set LAST_RUN_DTTM = datetime()
	where plan_id = &plan_id.;
quit;

%if &batch_process.=1 %then %do;

	data plan_scheduling_config;
		set uiart.plan_scheduling_config;
		where plan_id = input("&plan_id.",best12.);
		call symputx('recurrence',recurrence);
	run;

	%if &recurrence=0 %then %do;
		%let sas_interval=DAY;
	%end;
	%else %if &recurrence=1 %then %do;
		%let sas_interval=WEEK;
	%end;
	%else %if &recurrence=2 %then %do;
		%let sas_interval=MONTH;
	%end;
	%else %if &recurrence=3 %then %do;
		%let sas_interval=QTR;
	%end;
	%else %if &recurrence=4 %then %do;
		%let sas_interval=YEAR;
	%end;

	data _null_; 
		set plan_scheduling_config;	
		format next_dt date9. next_dttm datetime20.;
		next_dt=intnx("&sas_interval.", &curr_run_dt.,1,'same');
		next_dttm=next_dt *86400 + start_hour * 3600 + start_minute * 60;

		if next_dt  <= datepart(end_dt) and &curr_run_dt. <= datepart(end_dt) then do;
			call symputx('next_dttm',next_dttm);
		end;
		else do;
			call symputx('next_dttm',.);
		end;
	run;
	

	/* Update SCHEDULE_NEXT_RUN_DTTM if the stored process is run through scheduler */
/*	%if &update_next_dttm. =1 %then %do;*/
	proc sql;
		update uiart.plan_details  
		set SCHEDULE_NEXT_RUN_DTTM = &next_dttm.
		where plan_id = &plan_id.;
	quit;
/*	%end;*/

%end;

%mend;

%macro ddcf_batch_retrieve_data_diag ;

%global curr_run_dt;
%let curr_run_dt = date(); 
/*Assign transaction server library*/
%ddcf_assign_trans_library(libref=uiart);



%ddcf_connect_to_trans_db;
%ddcf_create_forecast_plan;
%ddcf_diagnose_forecast_plan;
%ddcf_uiart_batch_refresh;
%ddcf_upd_plan_run_dttm;

/*
Defect Id S1064284 
------------------
*/
%put &delete_scenario.;
%if &delete_scenario. = 1 %then %do;
	%ddcf_refresh_delete_scenario;
%end;

%if &GL_FAW_POSTGRES_IND. ne 1 %then %do;
	libname uiart clear;
%end;

%mend;
%ddcf_batch_retrieve_data_diag;
